@@ -1,7 +1,7 @@
 /*
  * Sleuth Kit Data Model
  *
- * Copyright 2011-2017 Basis Technology Corp.
+ * Copyright 2011-2019 Basis Technology Corp.
  * Contact: carrier <at> sleuthkit <dot> org
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -406,13 +406,12 @@ public class BlackboardArtifact implements Content {
 	public synchronized Content getParent() throws TskCoreException {
 		if (parent == null) {
 			ObjectInfo parentInfo;
-			try {
-				parentInfo = getSleuthkitCase().getParentInfo(this);
-			} catch (TskCoreException ex) {
-				// there is not parent; not an error if we've got a data source
-				return null;
+			parentInfo = getSleuthkitCase().getParentInfo(this);
+			if (parentInfo == null) {
+				parent = null;
+			} else {
+				parent = getSleuthkitCase().getContentById(parentInfo.getId());
 			}
-			parent = getSleuthkitCase().getContentById(parentInfo.getId());
 		}
 		return parent;
 	}
@@ -1145,7 +1144,69 @@ public class BlackboardArtifact implements Content {
 		 * A classifier detected an object in a media file.
 		 */
 		TSK_OBJECT_DETECTED(41, "TSK_OBJECT_DETECTED",  //NON-NLS
-				bundle.getString("BlackboardArtifact.tskObjectDetected.text"));
+				bundle.getString("BlackboardArtifact.tskObjectDetected.text")),
+		/**
+		 * A wireless network.
+		 */
+		TSK_WIFI_NETWORK(42, "TSK_WIFI_NETWORK",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskWIFINetwork.text")),
+		/**
+		 * Information related to a device.
+		 */
+		TSK_DEVICE_INFO(43, "TSK_DEVICE_INFO",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskDeviceInfo.text")),
+		/**
+		 * A SIM card.
+		 */
+		TSK_SIM_ATTACHED(44, "TSK_SIM_ATTACHED",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskSimAttached.text")),
+		/**
+		 * A bluetooth adapter.
+		 */
+		TSK_BLUETOOTH_ADAPTER(45, "TSK_BLUETOOTH_ADAPTER",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskBluetoothAdapter.text")),
+		/**
+		 * A wireless network adapter.
+		 */
+		TSK_WIFI_NETWORK_ADAPTER(46, "TSK_WIFI_NETWORK_ADAPTER",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskWIFINetworkAdapter.text")),
+		/**
+		 * Indicates a verification failure
+		 */
+		TSK_VERIFICATION_FAILED(47, "TSK_VERIFICATION_FAILED",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskVerificationFailed.text")),
+		/**
+		 * Categorization information for a data source.
+		 */
+		TSK_DATA_SOURCE_USAGE(48, "TSK_DATA_SOURCE_USAGE", //NON-NLS
+				bundle.getString("BlackboardArtifact.tskDataSourceUsage.text")),
+		/**
+		 * Indicates auto fill data from a Web form
+		 */
+		TSK_WEB_FORM_AUTOFILL(49, "TSK_WEB_FORM_AUTOFILL",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskWebFormAutofill.text")),
+		/**
+		 * Indicates an person's address filled in a web form
+		 */
+		TSK_WEB_FORM_ADDRESS (50, "TSK_WEB_FORM_ADDRESSES ",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskWebFormAddresses.text")),
+		/**
+		 * Indicates source of a file/object
+		 */
+		TSK_DOWNLOAD_SOURCE (51, "TSK_DOWNLOAD_SOURCE",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskDownloadSource.text")),
+		
+		/**
+		 * Indicates web cache data
+		 */
+		TSK_WEB_CACHE (52, "TSK_WEB_CACHE",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskWebCache.text")),
+		
+		/**
+		 * Indicates clipboard content
+		 */
+		TSK_CLIPBOARD_CONTENT (53, "TSK_CLIPBOARD_CONTENT",  //NON-NLS
+				bundle.getString("BlackboardArtifact.tskClipboardContent.text"));
 		
 		private final String label;
 		private final int typeId;
