@@ -1,7 +1,7 @@
 /*
  * Sleuth Kit Data Model
  *
- * Copyright 2018 Basis Technology Corp.
+ * Copyright 2018-2019 Basis Technology Corp.
  * Contact: carrier <at> sleuthkit <dot> org
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -68,6 +68,168 @@ public final class CaseDbAccessManager {
 		this.tskDB = skCase;
 	}
 
+	/**
+	 * Checks if a column exists in a table.
+	 *
+	 * @param tableName name of the table
+	 * @param columnName column name to check
+	 * 
+	 * @return true if the column already exists, false otherwise
+	 * @throws TskCoreException 
+	 */
+	public boolean columnExists(String tableName, String columnName) throws TskCoreException {
+		
+		boolean doesColumnExists = false;
+		CaseDbTransaction localTrans = tskDB.beginTransaction();
+        try {
+			doesColumnExists = columnExists(tableName, columnName, localTrans);
+			localTrans.commit();
+			localTrans = null;
+        } 
+		finally {
+			if (null != localTrans) {
+				try {
+					localTrans.rollback();
+				} catch (TskCoreException ex) {
+					logger.log(Level.SEVERE, "Failed to rollback transaction after exception", ex);
+				}
+			}
+		}
+		
+        return doesColumnExists;
+    }
+	
+	/**
+	 * Checks if a column exists in a table.
+	 *
+	 * @param tableName name of the table
+	 * @param columnName column name to check
+	 * @param transaction transaction 
+	 * 
+	 * @return true if the column already exists, false otherwise
+	 * @throws TskCoreException 
+	 */
+	public boolean columnExists(String tableName, String columnName, CaseDbTransaction transaction) throws TskCoreException {
+		
+		boolean columnExists = false;
+        Statement statement = null;
+		ResultSet resultSet = null;
+        try {
+			CaseDbConnection connection = transaction.getConnection();
+			statement = connection.createStatement();
+			if (DbType.SQLITE == tskDB.getDatabaseType()) {
+				String tableInfoQuery = "PRAGMA table_info(%s)";  //NON-NLS
+				resultSet = statement.executeQuery(String.format(tableInfoQuery, tableName));
+				while (resultSet.next()) {
+					if (resultSet.getString("name").equalsIgnoreCase(columnName)) {
+						columnExists = true;
+						break;
+					}
+				}
+			}
+			else {
+				String tableInfoQueryTemplate = "SELECT EXISTS (SELECT 1 FROM information_schema.columns WHERE table_name='%s' AND column_name='%s')";  //NON-NLS	
+				resultSet = statement.executeQuery(String.format(tableInfoQueryTemplate, tableName.toLowerCase(), columnName.toLowerCase()));
+				if (resultSet.next()) {
+					columnExists = resultSet.getBoolean(1);
+				}
+			}
+        } 
+		catch (SQLException ex) {
+			throw new TskCoreException("Error checking if column  " + columnName + "exists ", ex);
+		} 
+		finally {
+			if (resultSet != null) {
+				try {
+					resultSet.close();
+				} catch (SQLException ex2) {
+					logger.log(Level.WARNING, "Failed to to close resultset after checking column", ex2);
+				}
+			}
+            closeStatement(statement);
+        }
+        return columnExists;
+    }
+	
+	/**
+	 * Checks if a table exists in the case database.
+	 *
+	 * @param tableName name of the table to check
+	 * 
+	 * @return true if the table already exists, false otherwise
+	 * @throws TskCoreException 
+	 */
+	public boolean tableExists(String tableName) throws TskCoreException {
+		
+		boolean doesTableExist = false;
+		CaseDbTransaction localTrans = tskDB.beginTransaction();
+        try {
+			doesTableExist = tableExists(tableName, localTrans);
+			localTrans.commit();
+			localTrans = null;
+        } 
+		finally {
+			if (null != localTrans) {
+				try {
+					localTrans.rollback();
+				} catch (TskCoreException ex) {
+					logger.log(Level.SEVERE, "Failed to rollback transaction after exception", ex); //NON-NLS
+				}
+			}
+		}
+		
+        return doesTableExist;
+    }
+	
+	/**
+	 * Checks if a table exists in the case database.
+	 *
+	 * @param tableName name of the table to check
+	 * @param transaction transaction 
+	 * 
+	 * @return true if the table already exists, false otherwise
+	 * @throws TskCoreException 
+	 */
+	public boolean tableExists(String tableName, CaseDbTransaction transaction) throws TskCoreException {
+		
+		boolean tableExists = false;
+        Statement statement = null;
+		ResultSet resultSet = null;
+        try {
+			CaseDbConnection connection = transaction.getConnection();
+			statement = connection.createStatement();
+			if (DbType.SQLITE == tskDB.getDatabaseType()) {
+				resultSet = statement.executeQuery("SELECT name FROM sqlite_master WHERE type='table'");  //NON-NLS
+				while (resultSet.next()) {
+					if (resultSet.getString("name").equalsIgnoreCase(tableName)) { //NON-NLS
+						tableExists = true;
+						break;
+					}
+				}
+			}
+			else {
+				String tableInfoQueryTemplate = "SELECT EXISTS (SELECT 1 FROM information_schema.tables WHERE table_name='%s')";  //NON-NLS	
+				resultSet = statement.executeQuery(String.format(tableInfoQueryTemplate, tableName.toLowerCase()));
+				if (resultSet.next()) {
+					tableExists = resultSet.getBoolean(1);
+				}
+			}
+        } 
+		catch (SQLException ex) {
+			throw new TskCoreException("Error checking if table  " + tableName + "exists ", ex);
+		} finally {
+			if (resultSet != null) {
+				try {
+					resultSet.close();
+				} catch (SQLException ex2) {
+					logger.log(Level.WARNING, "Failed to to close resultset after checking table", ex2);
+				}
+			}
+            closeStatement(statement);
+        }
+        return tableExists;
+    }
+	
 	/**
 	 * Creates a table with the specified name and schema.
 	 * 
@@ -104,6 +266,72 @@ public final class CaseDbAccessManager {
 
 	}
 
+	/**
+	 * Alters a table with the specified name.
+	 * 
+	 * @param tableName name of the table to alter
+	 * @param alterSQL SQL to alter the table
+	 * 
+	 * @throws TskCoreException 
+	 */
+	public void alterTable(final String tableName, final String alterSQL) throws TskCoreException {
+		
+		CaseDbTransaction localTrans = tskDB.beginTransaction();
+		try {
+			alterTable(tableName, alterSQL, localTrans);
+			localTrans.commit();
+			localTrans = null;
+		} finally {
+			if (null != localTrans) {
+				try {
+					localTrans.rollback();
+				} catch (TskCoreException ex) {
+					logger.log(Level.SEVERE, "Failed to rollback transaction after exception", ex);
+				}
+			}
+		} 
+	}
+		
+	/**
+	 * Alters a table with the specified name.
+	 * 
+	 * @param tableName name of the table to alter
+	 * @param alterSQL SQL to alter the table
+	 * @param transaction transaction
+	 * 
+	 * @throws TskCoreException 
+	 */
+	public void alterTable(final String tableName, final String alterSQL, final CaseDbTransaction transaction) throws TskCoreException {
+
+		validateTableName(tableName);
+		validateSQL(alterSQL);
+
+		CaseDbConnection connection = transaction.getConnection();
+		transaction.acquireSingleUserCaseWriteLock();
+
+		Statement statement = null;
+		String sql = "ALTER TABLE " + tableName + " " + alterSQL;
+		
+		try {
+			statement = connection.createStatement();
+			statement.execute(sql);
+		} catch (SQLException ex) {
+			// SQLite occasionally returns false for columnExists() if a table was just created with that column
+			// leading to "duplicate column name" exception.
+			// We ignore this exception
+			if (DbType.SQLITE == tskDB.getDatabaseType() &&
+					alterSQL.toLowerCase().contains("add column") &&
+					ex.getMessage().toLowerCase().contains("duplicate column name")) {
+				logger.log(Level.WARNING, String.format("Column being added by SQL = %s already exists in table %s", alterSQL, tableName));
+				return;
+			}
+			throw new TskCoreException(String.format("Error altering table  %s with SQL = %s", tableName, sql), ex);
+		} finally {
+			closeStatement(statement);
+			// NOTE: write lock will be released by transaction
+		}
+	}
+	
 	/**
 	 * Creates an index on the specified table, on specified column(s).
 	 * 
@@ -157,14 +385,16 @@ public final class CaseDbAccessManager {
 		try {
 			long rowId = insert(tableName, sql, localTrans);
 			localTrans.commit();
+			localTrans = null;
 			return rowId;
-		} catch (TskCoreException ex) {
-			try {
-				localTrans.rollback();
-			} catch (TskCoreException ex2) {
-				logger.log(Level.SEVERE, String.format("Failed to rollback transaction after exception: %s", ex.getMessage()), ex2);
+		} finally {
+			if (null != localTrans) {
+				try {
+					localTrans.rollback();
+				} catch (TskCoreException ex) {
+					logger.log(Level.SEVERE, "Failed to rollback transaction after exception", ex);
+				}
 			}
-			throw ex;
 		} 
 		
 	}
@@ -240,14 +470,16 @@ public final class CaseDbAccessManager {
 		try {
 			long rowId = insertOrUpdate(tableName, sql, localTrans);
 			localTrans.commit();
+			localTrans = null;
 			return rowId;
-		} catch (TskCoreException ex) {
-			try {
-				localTrans.rollback();
-			} catch (TskCoreException ex2) {
-				logger.log(Level.SEVERE, String.format("Failed to rollback transaction after exception: %s", ex.getMessage()), ex2);
+		} finally {
+			if (null != localTrans) {
+				try {
+					localTrans.rollback();
+				} catch (TskCoreException ex) {
+					logger.log(Level.SEVERE, "Failed to rollback transaction after exception", ex);
+				}
 			}
-			throw ex;
 		} 
 		
 	}
@@ -315,13 +547,15 @@ public final class CaseDbAccessManager {
 		try {
 			update(tableName, sql, localTrans);
 			localTrans.commit();
-		} catch (TskCoreException ex) {
-			try {
-				localTrans.rollback();
-			} catch (TskCoreException ex2) {
-				logger.log(Level.SEVERE, String.format("Failed to rollback transaction after exception: %s", ex.getMessage()), ex2);
+			localTrans = null;
+		} finally {
+			if (null != localTrans) {
+				try {
+					localTrans.rollback();
+				} catch (TskCoreException ex) {
+					logger.log(Level.SEVERE, "Failed to rollback transaction after exception", ex);
+				}
 			}
-			throw ex;
 		} 
 	}
 	
