@@ -17,6 +17,7 @@
 #include "tsk/img/img_writer.h"
 #if HAVE_LIBEWF
 #include "tsk/img/ewf.h"
+#include "tsk/img/tsk_img_i.h"
 #endif
 #include <string.h>
 
@@ -208,6 +209,8 @@ uint8_t
 TskAutoDb::addImageDetails(const char* deviceId)
 {
    string md5 = "";
+   string sha1 = "";
+   string collectionDetails = "";
 #if HAVE_LIBEWF 
    if (m_img_info->itype == TSK_IMG_TYPE_EWF_EWF) {
      // @@@ This should really probably be inside of a tsk_img_ method
@@ -215,6 +218,11 @@ TskAutoDb::addImageDetails(const char* deviceId)
        if (ewf_info->md5hash_isset) {
            md5 = ewf_info->md5hash;
        }
+       if (ewf_info->sha1hash_isset) {
+           sha1 = ewf_info->sha1hash;
+       }
+
+       collectionDetails = ewf_get_details(ewf_info);   
    }
 #endif
 
@@ -225,7 +233,7 @@ TskAutoDb::addImageDetails(const char* deviceId)
         devId = "";
     }
     if (m_db->addImageInfo(m_img_info->itype, m_img_info->sector_size,
-          m_curImgId, m_curImgTZone, m_img_info->size, md5, "", "", devId)) {
+          m_curImgId, m_curImgTZone, m_img_info->size, md5, sha1, "", devId, collectionDetails)) {
         registerError();
         return 1;
     }
