@@ -672,94 +672,3 @@ tsk_UTF8toUTF16(const UTF8 ** sourceStart,
     return result;
 }
 
-TSKConversionResult
-tsk_UTF8toUTF16W(const UTF8 ** sourceStart,
-    const UTF8 * sourceEnd, wchar_t ** targetStart,
-    wchar_t * targetEnd, TSKConversionFlags flags)
-{
-    TSKConversionResult result = TSKconversionOK;
-    const UTF8 *source = *sourceStart;
-    wchar_t *target = *targetStart;
-    while (source < sourceEnd) {
-        UTF32 ch = 0;
-        unsigned short extraBytesToRead = trailingBytesForUTF8[*source];
-        if (source + extraBytesToRead >= sourceEnd) {
-            result = TSKsourceExhausted;
-            break;
-        }
-        /* Do this check whether lenient or strict */
-        if (!isLegalUTF8(source, extraBytesToRead + 1)) {
-            result = TSKsourceIllegal;
-            break;
-        }
-        /*
-         * The cases all fall through. See "Note A" below.
-         */
-        switch (extraBytesToRead) {
-        case 5:
-            ch += *source++;
-            ch <<= 6;           /* remember, illegal UTF-8 */
-        case 4:
-            ch += *source++;
-            ch <<= 6;           /* remember, illegal UTF-8 */
-        case 3:
-            ch += *source++;
-            ch <<= 6;
-        case 2:
-            ch += *source++;
-            ch <<= 6;
-        case 1:
-            ch += *source++;
-            ch <<= 6;
-        case 0:
-            ch += *source++;
-        }
-        ch -= offsetsFromUTF8[extraBytesToRead];
-
-        if (target >= targetEnd) {
-            source -= (extraBytesToRead + 1);   /* Back up source pointer! */
-            result = TSKtargetExhausted;
-            break;
-        }
-        if (ch <= TSK_UNI_MAX_BMP) {    /* Target is a character <= 0xFFFF */
-            /* UTF-16 surrogate values are illegal in UTF-32 */
-            if (ch >= UNI_SUR_HIGH_START && ch <= UNI_SUR_LOW_END) {
-                if (flags == TSKstrictConversion) {
-                    source -= (extraBytesToRead + 1);   /* return to the illegal value itself */
-                    result = TSKsourceIllegal;
-                    break;
-                }
-                else {
-                    *target++ = TSK_UNI_REPLACEMENT_CHAR;
-                }
-            }
-            else {
-                *target++ = (wchar_t) ch; /* normal case */
-            }
-        }
-        else if (ch > TSK_UNI_MAX_UTF16) {
-            if (flags == TSKstrictConversion) {
-                result = TSKsourceIllegal;
-                source -= (extraBytesToRead + 1);       /* return to the start */
-                break;          /* Bail out; shouldn't continue */
-            }
-            else {
-                *target++ = TSK_UNI_REPLACEMENT_CHAR;
-            }
-        }
-        else {
-            /* target is a character in range 0xFFFF - 0x10FFFF. */
-            if (target + 1 >= targetEnd) {
-                source -= (extraBytesToRead + 1);       /* Back up source pointer! */
-                result = TSKtargetExhausted;
-                break;
-            }
-            ch -= halfBase;
-            *target++ = (wchar_t) ((ch >> halfShift) + UNI_SUR_HIGH_START);
-            *target++ = (wchar_t) ((ch & halfMask) + UNI_SUR_LOW_START);
-        }
-    }
-    *sourceStart = source;
-    *targetStart = target;
-    return result;
-}
