@@ -19,6 +19,7 @@
 #if HAVE_LIBEWF
 
 #include <libewf.h>
+#include <string>
 
 // libewf version 2 no longer defines LIBEWF_HANDLE
 #undef HAVE_LIBEWF_V2_API
@@ -38,12 +39,16 @@ extern "C" {
         libewf_handle_t *handle;
         char md5hash[33];
         int md5hash_isset;
+        char sha1hash[41];
+        int sha1hash_isset;
         uint8_t used_ewf_glob;  // 1 if libewf_glob was used during open
         tsk_lock_t read_lock;   ///< Lock for reads since libewf is not thread safe -- only works if you have a single instance of EWF_INFO for all threads.
     } IMG_EWF_INFO;
 
+    
 #ifdef __cplusplus
 }
 #endif
+    extern std::string ewf_get_details(IMG_EWF_INFO *);
 #endif
 #endif
