@@ -149,7 +149,7 @@ raw_read_segment(IMG_RAW_INFO * raw_info, int idx, char *buf,
         //For physical drive when the buffer is larger than remaining data,
         // WinAPI ReadFile call returns -1
         //in this case buffer of exact length must be passed to ReadFile
-        if ((raw_info->is_winobj) && (rel_offset + len > raw_info->img_info.size ))
+        if ((raw_info->is_winobj) && (rel_offset + (TSK_OFF_T)len > raw_info->img_info.size ))
             len = (size_t)(raw_info->img_info.size - rel_offset);
 
         if (FALSE == ReadFile(cimg->fd, buf, (DWORD) len, &nread, NULL)) {
@@ -167,13 +167,23 @@ raw_read_segment(IMG_RAW_INFO * raw_info, int idx, char *buf,
         // We need to check if we've reached the end of a file and set nread to
         // the number of bytes read.
         if ((raw_info->is_winobj) && (nread == 0) && (rel_offset + len == raw_info->img_info.size)) {
-          nread = len;
+            nread = (DWORD)len;
         }
         cnt = (ssize_t) nread;
 
         if (raw_info->img_writer != NULL) {
             /* img_writer is not used with split images, so rel_offset is just the normal offset*/
-            raw_info->img_writer->add(raw_info->img_writer, rel_offset, buf, cnt);
+            TSK_RETVAL_ENUM result = raw_info->img_writer->add(raw_info->img_writer, rel_offset, buf, cnt);
+            // If WriteFile returns error in the addNewBlock, hadErrorExtending is 1
+            if (raw_info->img_writer->inFinalizeImageWriter && raw_info->img_writer->hadErrorExtending) {
+                tsk_error_reset();
+                tsk_error_set_errno(TSK_ERR_IMG_WRITE);
+                tsk_error_set_errstr("raw_read: file \"%" PRIttocTSK
+                    "\" offset: %" PRIuOFF " tsk_img_writer_add cnt: %" PRIuSIZE " - %d",
+                    raw_info->img_info.images[idx], rel_offset, cnt
+                    );
+                return -1;
+            }
         }
     }
 #else
@@ -257,7 +267,8 @@ raw_read(TSK_IMG_INFO * img_info, TSK_OFF_T offset, char *buf, size_t len)
             }
 
             /* Get the length to read */
-            if ((size_t) (raw_info->max_off[i] - offset) >= len)
+            // NOTE: max_off - offset can be a very large number.  Do not cast to size_t
+            if (raw_info->max_off[i] - offset >= (TSK_OFF_T)len)
                 read_len = len;
             else
                 read_len = (size_t) (raw_info->max_off[i] - offset);
@@ -283,18 +294,16 @@ raw_read(TSK_IMG_INFO * img_info, TSK_OFF_T offset, char *buf, size_t len)
 
                 len -= read_len;
 
-                while (len > 0) {
+                /* go to the next image segment */
+                while ((len > 0) && (i+1 < raw_info->img_info.num_img)) {
                     ssize_t cnt2;
-                    /* go to the next image segment */
+                    
                     i++;
 
-                    if ((size_t) (raw_info->max_off[i] -
-                        raw_info->max_off[i - 1]) >= len)
+                    if ((raw_info->max_off[i] - raw_info->max_off[i - 1]) >= (TSK_OFF_T)len)
                         read_len = len;
                     else
-                        read_len = (size_t)
-                            (raw_info->max_off[i] -
-                            raw_info->max_off[i - 1]);
+                        read_len = (size_t) (raw_info->max_off[i] - raw_info->max_off[i - 1]);
 
                     if (tsk_verbose) {
                         tsk_fprintf(stderr,
